package dpl;

use dpl::grammar;

require 5.6.0;
use strict;
use warnings;
use Carp;
use MLDBM qw(DB_File);
use DB_File;

use POSIX;
use Data::Dumper;
setlocale(LC_CTYPE,"ISO-8859-1");

require Exporter;
require DynaLoader;
use AutoLoader;

our @ISA = qw(Exporter DynaLoader);

# Items to export into callers namespace by default. Note: do not export
# names by default without a very good reason. Use EXPORT_OK instead.
# Do not simply export all your public functions/methods/constants.

# This allows declaration	use dpl ':all';
# If you do not need this, moving things directly into @EXPORT or @EXPORT_OK
# will save memory.
our %EXPORT_TAGS = ( 'all' => [ qw() ] );

our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );

our @EXPORT = qw();
our $VERSION = '0.04';



sub AUTOLOAD {
    # This AUTOLOAD is used to 'autoload' constants from the constant()
    # XS function.  If a constant is not found then control is passed
    # to the AUTOLOAD in AutoLoader.

    my $constname;
    our $AUTOLOAD;
    ($constname = $AUTOLOAD) =~ s/.*:://;
    croak "& not defined" if $constname eq 'constant';
    my $val = constant($constname, @_ ? $_[0] : 0);
    if ($! != 0) {
	if ($! =~ /Invalid/ || $!{EINVAL}) {
	    $AutoLoader::AUTOLOAD = $AUTOLOAD;
	    goto &AutoLoader::AUTOLOAD;
	}
	else {
	    croak "Your vendor has not defined dpl macro $constname";
	}
    }
    {
	no strict 'refs';
	# Fixed between 5.005_53 and 5.005_61
	if ($] >= 5.00561) {
	    *$AUTOLOAD = sub () { $val };
	}
	else {
	    *$AUTOLOAD = sub { $val };
	}
    }
    goto &$AUTOLOAD;
}

bootstrap dpl $VERSION;

sub yylex {
  return (plex(),plextext());
}

sub yyerror {
  my $msg = shift;
  my $lineno = plexlineno();
  my $text = plextext();
  warn "$msg at line $lineno near '$text'.\n";
}

sub opendb{
    my $filename=shift or die("usage ... filename\n");
    my %h;
    tie %h, 'MLDBM' , "$filename.db" , O_RDWR, 0, $DB_BTREE  or warn $! ;
    return bless { 'filename'=> $filename,
                   'h' => \%h,
                   'meta'=> $h{'!meta'},
                 }
}

sub closedb{
    my $self=shift;
    untie $self->{h};
}

1;
__END__

=head1 NAME

dpl - Perl implementation for a Dictionary Programming Language parser

=head1 SYNOPSYS

 use dpl;

=head1 DESCRIPTION

DPL is a programming language for dictionary construction. This module
implements a generic parser to this language and provides some built-in
commands to make various different outputs.

=head1 REPORTING BUGS

Send bug reports to one of the authors. Allways possible, send
a simple example demonstrating the bug.

=head1 AUTHORS

Jos Joo Almeida <jj@di.uminho.pt>

Alberto Simes <albie@alfarrabio.di.uminho.pt>

=head1 SEE ALSO

The perl manpage.

=head1 COPYRIGHT

Copyright (C) 2001 Minho's University: Portugal (GPL)

=cut


